@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef BASEMODEL_H
-#define BASEMODEL_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QKeySequence>
@@ -14,6 +13,21 @@
 
 class KConfigBase;
 
+// we need to do this to expose the enum to QML
+namespace ComponentNS
+{
+Q_NAMESPACE
+enum ComponentType {
+    Application,
+    Command,
+    SystemService,
+    CommonAction,
+};
+Q_ENUM_NS(ComponentType)
+};
+
+using namespace ComponentNS;
+
 struct Action {
     QString id;
     QString displayName;
@@ -25,7 +39,7 @@ struct Action {
 struct Component {
     QString id;
     QString displayName;
-    QString type;
+    ComponentType type;
     QString icon;
     QVector<Action> actions;
     bool checked;
@@ -77,5 +91,3 @@ public:
 protected:
     QVector<Component> m_components;
 };
-
-#endif
