@@ -9,10 +9,10 @@
 
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KWindowSystem>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QDBusPendingCall>
 
 #include "workspaceoptions_kdeglobalssettings.h"
 #include "workspaceoptions_kwinsettings.h"
@@ -47,13 +47,10 @@ WorkspaceOptionsKwinSettings *KCMWorkspaceOptions::kwinSettings() const
     return m_data->workspaceOptionsKwinSettings();
 }
 
-bool KCMWorkspaceOptions::isWayland() const
-{
-    return KWindowSystem::isPlatformWayland();
-}
-
 void KCMWorkspaceOptions::save()
 {
+    const bool primarySelectionSaved = m_data->workspaceOptionsKwinSettings()->findItem(QStringLiteral("primarySelection"))->isSaveNeeded();
+
     ManagedConfigModule::save();
 
     {
@@ -73,6 +70,19 @@ void KCMWorkspaceOptions::save()
         message.setArguments({QVariant::fromValue(changes)});
         QDBusConnection::sessionBus().send(message);
     }
+
+    if (primarySelectionSaved) {
+        Q_EMIT primarySelectionOptionSaved();
+    }
+}
+
+void KCMWorkspaceOptions::requestReboot()
+{
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.LogoutPrompt"),
+                                                      QStringLiteral("/LogoutPrompt"),
+                                                      QStringLiteral("org.kde.LogoutPrompt"),
+                                                      QStringLiteral("promptReboot"));
+    QDBusConnection::sessionBus().asyncCall(msg);
 }
 
 #include "moc_workspaceoptions.cpp"
